// Emacs style mode select   -*- C++ -*-
//-----------------------------------------------------------------------------
//
// $Id: 58d7c54742d6b91c19efc46cba22e82265d8878d $
//
// Copyright (C) 1993-1996 by id Software, Inc.
// Copyright (C) 2006-2025 by The Odamex Team.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// DESCRIPTION:
//  AutoMap module.
//
//-----------------------------------------------------------------------------

#include "odamex.h"
#include "am_map.h"

void AM_SetBaseColorDoom()
{

}

void AM_SetBaseColorRaven()
{

}

void AM_SetBaseColorStrife()
{

}

void AM_Start()
{

}

bool AM_Responder(event_t* ev)
{
	return false;
}

void AM_Drawer()
{

}

VERSION_CONTROL(am_map_cpp, "$Id: 58d7c54742d6b91c19efc46cba22e82265d8878d $")
